class NetworkError(Exception):
    def __init__(self, error: str):
        super().__init__(error)


class TCPServerOccupiedError(NetworkError):
    def __init__(self, server_name):
        super().__init__(
            "%s has been occupied Note:TCP Server Currently \
Only Support A Single Client" % str(server_name))


class CommParserError(NetworkError):
    pass


class CommResourceError(NetworkError):
    pass


class CommNotConnectError(NetworkError):
    pass


class InvaildPlugin(CommResourceError):
    def __init__(self, module: str, plugin: str):
        super().__init__("Can not find plugin(%s.%s)." % (str(module), str(plugin)))


class InvaildModule(CommResourceError):
    def __init__(self, module: str):
        super().__init__("Can not find module(%s)." % str(module))


class InvaildMethod(CommParserError):
    def __init__(self, method: str):
        super().__init__("Can not parser method(%s)." % str(method))


class InvaildJsonMsg(CommParserError):
    def __init__(self, e: Exception):
        super().__init__("Message can not convert to json object: %s." % str(e))


class RpcIdInvaild(CommParserError):
    def __init__(self):
        super().__init__("rpc id is not int type.")


class RpcVersionInvaild(CommParserError):
    def __init__(self):
        super().__init__("rpc version is not 2.0.")


class RpcMethodMiss(CommParserError):
    def __init__(self):
        super().__init__("method is missing.")



from .NetworkError import NetworkError
from .RPCClient import RPCClient
from .RPCServer import RPCServer
from .RPCClientAdapter import DobotlinkAdapter, NormalAdapter
# from .RPCServerAdapter import ModuleAdapter, GUIAdapter
from .Utils import loggers

__all__ = ("loggers", "RPCClient", "RPCServer", "DobotlinkAdapter", "NormalAdapter",
           "NetworkError")



# python3
# -*- encoding: utf-8 -*-
"""
@Author:
    JoMar Wu (sos901012@gmail.com)
@Create Time:
    2019-08-28 18:07:25
@License:
    Copyright © 2019 Shenzhen Yuejiang Co., Ltd.
@Desc:
    None
"""
from typing import List, Any


class MessageCenterError(Exception):
    pass


class IsNotMessageHandler(MessageCenterError):
    def __init__(self, obj: object):
        super().__init__("%s is not MessageHandler." % str(obj))


class MustRegisterOrphan(MessageCenterError):
    def __init__(self):
        super().__init__("Must register orphan.")


class CannotFoundModule(MessageCenterError):
    def __init__(self, name: object):
        super().__init__("%s can not found." % str(name))


class CannotFoundFunc(MessageCenterError):
    def __init__(self, name: object):
        super().__init__("%s can not found." % str(name))


class InvalidMethodFormat(MessageCenterError):
    def __init__(self, method: object):
        super().__init__("%s" % str(method))


class CanNotFoundCallback(MessageCenterError):
    def __init__(self, callback_id: object):
        super().__init__("callback(%s) can not found." % str(callback_id))


class InvaildCallback(MessageCenterError):
    def __init__(self, obj: object):
        super().__init__("objest(%s) is not callable." % str(obj))


class InvaildParams(MessageCenterError):
    def __init__(self, args: List[Any]):
        super().__init__("%s is invaild params." % str(args))


class CannotFoundMethod(MessageCenterError):
    pass